@@ -16,6 +16,7 @@
 import time
 
 from gazoo_device import config
+from gazoo_device import console_config
 from gazoo_device import decorators
 from gazoo_device import detect_criteria
 from gazoo_device import errors
@@ -125,6 +126,11 @@ class UnifiPoeSwitch(auxiliary_device.AuxiliaryDevice):
         command=self.commands["FIRMWARE_VERSION"],
         regex=self._regexes["FIRMWARE_VERSION_REGEX"])
 
+  def get_console_configuration(self) -> console_config.ConsoleConfiguration:
+    """Returns the interactive console configuration."""
+    return console_config.get_log_response_separate_port_configuration(
+        self.switchboard.get_line_identifier())
+
   @decorators.PersistentProperty
   def health_checks(self):
     """Returns list of methods to execute as health checks."""
@@ -346,7 +352,7 @@ class UnifiPoeSwitch(auxiliary_device.AuxiliaryDevice):
           "device_name": self.name,
           "event_parser": None})
       setattr(self, switchboard_name,
-              self.manager_weakref().create_switchboard(**switchboard_kwargs))
+              self.get_manager().create_switchboard(**switchboard_kwargs))
 
     return getattr(self, switchboard_name)
 
