@@ -19,6 +19,10 @@ re-implemented in derived device classes. Device classes should inherit from
 AuxiliaryDevice, not from this class.
 """
 import abc
+from typing import Optional
+
+from gazoo_device import console_config
+from gazoo_device import data_types
 
 
 class AuxiliaryDeviceBase(abc.ABC):
@@ -47,6 +51,11 @@ class AuxiliaryDeviceBase(abc.ABC):
   def connected(self):
     """Returns whether the device is connected or not."""
 
+  @abc.abstractmethod
+  def get_console_configuration(
+      self) -> Optional[console_config.ConsoleConfiguration]:
+    """Returns interactive console configuration or None if not supported."""
+
   @abc.abstractproperty
   def health_checks(self):
     """Returns list of methods to execute as health checks."""
@@ -136,7 +145,8 @@ class AuxiliaryDeviceBase(abc.ABC):
     """
 
   @abc.abstractmethod
-  def make_device_ready(self, setting: str = "on") -> None:
+  def make_device_ready(
+      self, setting: data_types.MAKE_DEVICE_READY_SETTING = "on") -> None:
     """Checks device readiness and attempts recovery if allowed.
 
     If setting is 'off': does nothing.
