@@ -17,6 +17,7 @@ import re
 import time
 
 from gazoo_device import config
+from gazoo_device import console_config
 from gazoo_device import decorators
 from gazoo_device import errors
 from gazoo_device import gdm_logger
@@ -140,6 +141,11 @@ class RaspbianDevice(auxiliary_device.AuxiliaryDevice):
         self.regexes["FIRMWARE_VERSION_REGEX"],
         raise_error=True)
 
+  def get_console_configuration(self) -> console_config.ConsoleConfiguration:
+    """Returns the interactive console configuration."""
+    return console_config.get_log_response_separate_port_configuration(
+        self.switchboard.get_line_identifier())
+
   @decorators.PersistentProperty
   def health_checks(self):
     """Returns list of methods to execute as health checks."""
@@ -331,7 +337,7 @@ class RaspbianDevice(auxiliary_device.AuxiliaryDevice):
           "device_name": self.name,
           "event_parser": None})
       setattr(self, switchboard_name,
-              self.manager_weakref().create_switchboard(**switchboard_kwargs))
+              self.get_manager().create_switchboard(**switchboard_kwargs))
 
     return getattr(self, switchboard_name)
 
